@@ -2,8 +2,8 @@
 
 base_dir = File.expand_path(File.join(File.dirname(__FILE__), ".."))
 test_unit_dir = File.join(base_dir, "test-unit", "lib")
-src_dir = File.join(base_dir, "src")
-lib_dir = File.join(src_dir, "lib")
+ext_dir = File.join(base_dir, "ext", "cairo")
+lib_dir = File.join(base_dir, "lib")
 test_dir = File.join(base_dir, "test")
 
 if system("which make > /dev/null")
@@ -15,7 +15,7 @@ $LOAD_PATH.unshift(test_unit_dir)
 require 'test/unit'
 
 $LOAD_PATH.unshift(base_dir)
-$LOAD_PATH.unshift(src_dir)
+$LOAD_PATH.unshift(ext_dir)
 $LOAD_PATH.unshift(lib_dir)
 
 $LOAD_PATH.unshift(test_dir)
